# FOSSLight Dependency
![FOSSLight](https://user-images.githubusercontent.com/50347670/112098530-4c5f0780-8be5-11eb-91af-6e13c86ef339.jpg)

## Introduction
This is the tool that supports the analysis of dependencies for multiple package managers. It detects the manifest file of package managers automatically and analyzes the dependencies with using open source tools. Then, it generates the report file that contains OSS information of dependencies.

Currently, it supports the following package managers.
* [Gradle](https://gradle.org/) (Java)
* [Maven](http://maven.apache.org/) (Java)
* [NPM](https://www.npmjs.com/) (Node.js)
* [PIP](https://pip.pypa.io/) (Python)
* [Pub](https://pub.dev/) (Dart with flutter)
* [Cocoapods](https://cocoapods.org/) (Swift/Obj-C)


## User Guide
Please see the [User Guide](/docs/user-guide.md) for more information on how to run each package manager.

## License
[![License](https://img.shields.io/badge/License-Apache%202.0-orange.svg)](https://opensource.org/licenses/Apache-2.0)

Unless otherwise specified, all content, including all source code files and documentation files in this repository are:

Copyright (c) 2020 LG Electronics, Inc.

All content, including all source code files and documentation files in this repository except otherwise noted are: Licensed under the Apache License, Version 2.0 (the "License"); you may not use this content except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

SPDX-License-Identifier: Apache-2.0


